import React from 'react';
import Uuid from 'uuid';
import classnames from 'classnames';
import PropTypes from 'prop-types';
import './icon.less';
import { renderIconPath, getViewBox } from './_path';

export default function Icon({ color, iconType, id, size, subClass }) {
    const className = classnames(
        'tsdev-icon', subClass
    );
    const inlineStyle = {
        fill: color,
        width: size,
        height: size
    };

    return (
        <svg id={id}
            width={size}
            height={size}
            viewBox={getViewBox(iconType)}
            className={className}
            style={inlineStyle}>
            {renderIconPath(iconType)}
        </svg>
    );
}

Icon.propTypes = {
    color: PropTypes.string,
    iconType: PropTypes.string,
    id: PropTypes.string,
    size: PropTypes.number,
    subClass: PropTypes.string
};

Icon.defaultProps = {
    color: '#111111',
    iconType: 'arrow-left',
    id: `dipatIcon-${Uuid.v4()}`,
    size: 50,
    subClass: ''
};

Icon.displayName = 'Icon';
