import React from 'react';
import keys from 'lodash/keys';
import { shallow, mount } from 'enzyme';
import { Alert } from './../../../index';

describe('| components | Alert', () => {

    const component = (<Alert />);
    const expectedNumberOfProps = 6;

    let wrapper;

    it('Ensure component class name', () => {
        wrapper = shallow(component);
        expect(wrapper.getElement(0).props.className).toBe('tsdev-alert info');
        wrapper = shallow(<Alert subClass="abc def" />);
        expect(wrapper.getElement(0).props.className).toBe('tsdev-alert info abc def');
    });

    it('Ensure number of properties', () => {
        expect(keys(component.props).length).toBe(expectedNumberOfProps);
    });

    it('Ensure number of prop-types', () => {
        expect(keys(Alert.propTypes).length).toBe(expectedNumberOfProps);
    });

    describe('| coverage improvement |', () => {

        it('Ensure prop alertType: spinner', () => {
            wrapper = mount(<Alert alertType="spinner" />);
            expect(wrapper.props().alertType).toBe('spinner');
        });

        it('Ensure prop showIcon: false', () => {
            wrapper = mount(<Alert showIcon={false} />);
            expect(wrapper.props().showIcon).toBe(false);
        });

    });

});
