import React from 'react';
import keys from 'lodash/keys';
import { shallow, mount } from 'enzyme';
import { Dialog } from './../../../index';

describe('| components | Dialog', () => {

    const component = (<Dialog />);
    const expectedNumberOfProps = 18;

    let wrapper;

    it('Ensure component class name', () => {
        wrapper = shallow(component);
        expect(wrapper.getElement(0).props.className).toBe('tsdev-dialog');
        wrapper = shallow(<Dialog subClass="abc def" />);
        expect(wrapper.getElement(0).props.className).toBe('tsdev-dialog abc def');
    });

    it('Ensure number of properties', () => {
        expect(keys(component.props).length).toBe(expectedNumberOfProps);
    });

    it('Ensure number of prop-types', () => {
        expect(keys(Dialog.propTypes).length).toBe(expectedNumberOfProps);
    });

    describe('| functionality |', () => {

        const mockFunction = jest.fn();

        it('Ensure function onClose', () => {
            wrapper = mount(<Dialog onClose={mockFunction}
                isClosable />);
            wrapper.find('.close-icon').simulate('click');
            expect(mockFunction).toHaveBeenCalled();
        });
    });

    describe('| coverage improvement |', () => {

        it('Ensure function isClosable: false', () => {
            wrapper = mount(<Dialog isClosable={false} />);
            expect(wrapper.props().isClosable).toBe(false);
        });

        it('Ensure function showHeader: false', () => {
            wrapper = mount(<Dialog showHeader={false} />);
            expect(wrapper.props().showHeader).toBe(false);
        });

        it('Ensure function showFooter: false', () => {
            wrapper = mount(<Dialog showFooter={false} />);
            expect(wrapper.props().showFooter).toBe(false);
        });

        it('Ensure function isOpen: true', () => {
            wrapper = mount(<Dialog isOpen />);
            expect(wrapper.props().isOpen).toBe(true);
        });

        it('Ensure function isModal: true', () => {
            wrapper = mount(<Dialog isModal
                isOpen />);
            expect(wrapper.props().isModal).toBe(true);
        });

    });

});
