import React from 'react';
import keys from 'lodash/keys';
import { shallow, mount } from 'enzyme';
import { Icon } from './../../../index';

describe('| components | Icon', () => {

    const component = (<Icon />);
    const expectedNumberOfProps = 5;

    let wrapper;

    it('Ensure component class name', () => {
        wrapper = shallow(component);
        expect(wrapper.getElement(0).props.className).toBe('tsdev-icon');
        wrapper = shallow(<Icon subClass="abc def" />);
        expect(wrapper.getElement(0).props.className).toBe('tsdev-icon abc def');
    });

    it('Ensure number of properties', () => {
        expect(keys(component.props).length).toBe(expectedNumberOfProps);
    });

    it('Ensure number of prop-types', () => {
        expect(keys(Icon.propTypes).length).toBe(expectedNumberOfProps);
    });

    describe('| coverage improvement |', () => {

        it('Ensure prop iconType: arrow-down', () => {
            wrapper = mount(<Icon iconType="arrow-down" />);
            expect(wrapper.props().iconType).toBe('arrow-down');
        });

        it('Ensure prop iconType: arrow-right', () => {
            wrapper = mount(<Icon iconType="arrow-right" />);
            expect(wrapper.props().iconType).toBe('arrow-right');
        });

        it('Ensure prop iconType: arrow-up', () => {
            wrapper = mount(<Icon iconType="arrow-up" />);
            expect(wrapper.props().iconType).toBe('arrow-up');
        });

        it('Ensure prop iconType: calendar', () => {
            wrapper = mount(<Icon iconType="calendar" />);
            expect(wrapper.props().iconType).toBe('calendar');
        });

        it('Ensure prop iconType: check', () => {
            wrapper = mount(<Icon iconType="check" />);
            expect(wrapper.props().iconType).toBe('check');
        });

        it('Ensure prop iconType: dot', () => {
            wrapper = mount(<Icon iconType="dot" />);
            expect(wrapper.props().iconType).toBe('dot');
        });

        it('Ensure prop iconType: emergency', () => {
            wrapper = mount(<Icon iconType="emergency" />);
            expect(wrapper.props().iconType).toBe('emergency');
        });

        it('Ensure prop iconType: exclamination', () => {
            wrapper = mount(<Icon iconType="exclamination" />);
            expect(wrapper.props().iconType).toBe('exclamination');
        });

        it('Ensure prop iconType: mail', () => {
            wrapper = mount(<Icon iconType="mail" />);
            expect(wrapper.props().iconType).toBe('mail');
        });

        it('Ensure prop iconType: user', () => {
            wrapper = mount(<Icon iconType="user" />);
            expect(wrapper.props().iconType).toBe('user');
        });

        it('Ensure prop iconType: pen', () => {
            wrapper = mount(<Icon iconType="pen" />);
            expect(wrapper.props().iconType).toBe('pen');
        });

        it('Ensure prop iconType: plus', () => {
            wrapper = mount(<Icon iconType="plus" />);
            expect(wrapper.props().iconType).toBe('plus');
        });

        it('Ensure prop iconType: trash', () => {
            wrapper = mount(<Icon iconType="trash" />);
            expect(wrapper.props().iconType).toBe('trash');
        });

        it('Ensure prop iconType: heart', () => {
            wrapper = mount(<Icon iconType="heart" />);
            expect(wrapper.props().iconType).toBe('heart');
        });

        it('Ensure prop iconType: map-marker', () => {
            wrapper = mount(<Icon iconType="map-marker" />);
            expect(wrapper.props().iconType).toBe('map-marker');
        });

        it('Ensure prop iconType: close', () => {
            wrapper = mount(<Icon iconType="close" />);
            expect(wrapper.props().iconType).toBe('close');
        });

        it('Ensure prop iconType: warning', () => {
            wrapper = mount(<Icon iconType="warning" />);
            expect(wrapper.props().iconType).toBe('warning');
        });

        it('Ensure prop iconType: info', () => {
            wrapper = mount(<Icon iconType="info" />);
            expect(wrapper.props().iconType).toBe('info');
        });

        it('Ensure prop iconType: error', () => {
            wrapper = mount(<Icon iconType="error" />);
            expect(wrapper.props().iconType).toBe('error');
        });

        it('Ensure prop iconType: fatal', () => {
            wrapper = mount(<Icon iconType="fatal" />);
            expect(wrapper.props().iconType).toBe('fatal');
        });
    });

});
