import React from 'react';
import keys from 'lodash/keys';
import { shallow, mount } from 'enzyme';
import { Label } from './../../../index';

describe('| components | Label', () => {

    const component = (<Label />);
    const expectedNumberOfProps = 5;

    let wrapper;

    it('Ensure component class name', () => {
        wrapper = shallow(component);
        expect(wrapper.getElement(0).props.className).toBe('tsdev-label');
        wrapper = shallow(<Label subClass="abc def" />);
        expect(wrapper.getElement(0).props.className).toBe('tsdev-label abc def');
    });

    it('Ensure number of properties', () => {
        expect(keys(component.props).length).toBe(expectedNumberOfProps);
    });

    it('Ensure number of prop-types', () => {
        expect(keys(Label.propTypes).length).toBe(expectedNumberOfProps);
    });

    describe('| coverage improvement |', () => {

        it('Ensure prop labelType: spinner', () => {
            wrapper = mount(<Label labelType="spinner" />);
            expect(wrapper.props().labelType).toBe('spinner');
        });

        it('Ensure prop showIcon: false', () => {
            wrapper = mount(<Label showIcon={false} />);
            expect(wrapper.props().showIcon).toBe(false);
        });

    });

});
