import React from 'react';
import keys from 'lodash/keys';
import { shallow, mount } from 'enzyme';
import { Panel } from './../../../index';

describe('| components | Panel', () => {

    const component = (<Panel />);
    const expectedNumberOfProps = 8;

    let wrapper;

    it('Ensure component class name', () => {
        wrapper = shallow(component);
        expect(wrapper.getElement(0).props.className).toBe('tsdev-panel');
        wrapper = shallow(<Panel subClass="abc def" />);
        expect(wrapper.getElement(0).props.className).toBe('tsdev-panel abc def');
    });

    it('Ensure number of properties', () => {
        expect(keys(component.props).length).toBe(expectedNumberOfProps);
    });

    it('Ensure number of prop-types', () => {
        expect(keys(Panel.propTypes).length).toBe(expectedNumberOfProps);
    });

    describe('| functionality |', () => {

        const mockFunction = jest.fn();

        it('Ensure function onToggle', () => {
            wrapper = mount(<Panel onToggle={mockFunction} />);
            wrapper.find('.panel-header').simulate('click');
            expect(mockFunction).toHaveBeenCalled();
        });
    });

});
